====================
data-management-demo
====================


.. image:: https://img.shields.io/pypi/v/data_management_demo.svg
        :target: https://pypi.python.org/pypi/data_management_demo

.. image:: https://img.shields.io/travis/julianpitney/data_management_demo.svg
        :target: https://travis-ci.com/julianpitney/data_management_demo

.. image:: https://readthedocs.org/projects/data-management-demo/badge/?version=latest
        :target: https://data-management-demo.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Boilerplate for data management demo python package


* Free software: MIT license
* Documentation: https://data-management-demo.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
